<?php

declare(strict_types=1);

/**
 * This file is part of Hyperf.
 *
 * @link     https://www.hyperf.io
 * @document https://hyperf.wiki
 * @contact  group@hyperf.io
 * @license  https://github.com/hyperf/hyperf/blob/master/LICENSE
 */

use App\Controller\CompanyController;
use App\Controller\FirstCompanyController;
use App\Controller\PurchaseController;
use App\Controller\RoleController;
use App\Controller\SystemController;
use App\Controller\UserController;
use App\Middleware\CheckTokenMiddleware;
use App\Middleware\PermissionVerifyMiddleware;
use Hyperf\HttpServer\Router\Router;

Router::get('/favicon.ico', function () {
    return '';
});


Router::addGroup('/api/v1/', function () {
    Router::post('user.login', [UserController::class, 'userLogin']);   # 用户登录
});

Router::addGroup('/api/v1', function () {
    // 需携带 Token 接口
    Router::addGroup('/', function () {
        Router::post('user.logout', [UserController::class, 'userLogout']); # 用户登出

        Router::get('menu.list', [SystemController::class, 'menuList']);    # 系统菜单列表
    });

    // 需携带 Token 接口且需验证权限
    Router::addGroup('/', function () {
        /**
         * 用户管理
         */
        Router::post('user.add', [UserController::class, 'addUser']);           # 新增用户
        Router::post('user.list', [UserController::class, 'getUserList']);      # 获取用户列表
        Router::post('user.import', [UserController::class, 'importUser']);     # 批量导入用户信息

        /**
         * 角色管理
         */
        Router::post('role.add', [RoleController::class, 'addRole']);               # 新增角色
        Router::post('role.list', [RoleController::class, 'roleList']);             # 获取角色列表
        Router::post('roles.status', [RoleController::class, 'disableRoles']);      # 禁用&启用角色
        Router::post('roles.delete', [RoleController::class, 'delRoles']);          # 删除角色
        Router::post('assign.user.role', [RoleController::class, 'assignUserRoles']);           # 分配用户角色
        Router::post('assign.role.auth', [RoleController::class, 'assignRolePermissions']);     # 角色授权
        Router::post('role.permission.checked', [RoleController::class, 'roleChecked']);        # 角色权限选择列表

        // 平台公司管理
        Router::post('company.module.add', [RoleController::class, 'addCompanyModule']);        # 公司模块授权
        Router::post('company.permission.checked', [RoleController::class, 'companyChecked']);  # 公司模块选择列表

        /**
         * 采购入库管理
         */
        Router::post('purchase.add', [PurchaseController::class, 'addPurchase']);   # 新增采购入库单

        /**
         * 平台管理
         */
        Router::post('company.add.first', [FirstCompanyController::class, 'addFirstCompany']);   # 新增平台公司

        /**
         * 供应商&客户管理
         */
        Router::post('company.add', [CompanyController::class, 'addCompany']);      # 新增公司
    }, ['middleware' => [PermissionVerifyMiddleware::class]]);
}, ['middleware' => [CheckTokenMiddleware::class]]);